.. _math:

=====================================
Mathematical utilities (`skhep.math`)
=====================================

.. automodule:: skhep.math
   :members:

.. automodule:: skhep.math.kinematics
   :members:

.. automodule:: skhep.math.vectors
   :members:

.. automodule:: skhep.math.geometry
   :members:
